import request from "@/utils/request";

//实施人员下拉框
export function getUserListByDeptId(data) {
    return request({
        url: '/user-boot/user/getUserListByDeptId',
        method: 'get',
        params:data,

    })
}
//分页查询预告警单反馈
export function pageAlarmBack(data) {
    return request({
        url: '/process-boot/supvAlarmBack/pageAlarmBack',
        method: 'post',
        data,

    })
}
//修改预告警单反馈
export function updateAlarmBack(data) {
    return request({
        url: '/process-boot/supvAlarmBack/updateAlarmBack',
        method: 'post',
        data,

    })
}
//删除预告警单反馈
export function delAlarmBack(data) {
    return request({
        url: '/process-boot/supvAlarmBack/delAlarmBack',
        method: 'post',
        data,

    })
}
//推送电能质量技术监督预告警单反馈数据接口
export function pushAlarmHis(data) {
    return request({
        url: '/process-boot/supv/push/pushAlarmHis',
        method: 'post',
        data,

    })
}
//导出预告警单反馈数据信息
export function downAlarmBack(data) {
    return request({
        url: '/process-boot/supvAlarmBack/downAlarmBack',
        method: 'post',
        params:data,
        responseType: 'blob'

    })
}